/*
 * _1ch433remT.c
 *
 * Created: 03.03.2017 13:02:51
 *  Author: dsosnowski
 */ 


/*
 * rxtx433.c
 *
 * Created: 2016-08-03 14:23:01
 *  Author: dsosnowski
 */ 

//----------------------------------------------------
#define F_CPU 12000000
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "simple_r.h"
#include "ui.h"
#include "wdog.h"
#include "ee_mem.h"
#include "defs.h"

//----------------------------------------------------
#define EE_ADR_LOCATION		23
#define EE_ADR_MAXVAL		24
#define EE_ADR_DEFAULT		1

//----------------------------------------------------
void HardInit(void);
uint8_t AddressProc(uint8_t new);
//----------------------------------------------------
struct {
	uint8_t mode;
	uint8_t address;
	uint16_t led;
}system;

//----------------------------------------------------
int main(void)
{
	uint8_t ui = 0;
	uint8_t blink = 0;
	
	HardInit();
	UiInit();
	system.address = AddressProc(0);
	
    while(1) {
		
		//--------------------------------------------------------
		ui = UiButtonProc();

		//--------------------------------------------------------
		if (system.mode == MODE_IDLE) {
			
			if (ui == BUTTON_MIAN) {
				system.mode = MODE_NORMAL;
				SimplerFramePrepare((system.address * OUT_ADR_CALC), OUT1_COMMAND);
				SimplerInit();
				sei();	
			}
			
			if (ui == (BUTTON_CFG + BUTTON_HOLD)) {
				system.mode = MODE_CONFIG;
				UiLed(0);
				_delay_ms(200);
			}

			ui = 0;
		}
		
		//--------------------------------------------------------
		if (system.mode == MODE_NORMAL) {
			SimplerTransmitRun(1);	
		}
		
		//--------------------------------------------------------
		if (system.mode == MODE_CONFIG) {
			
			if (ui == BUTTON_CFG) {
				system.address++;
				AddressProc(system.address);
				system.address = AddressProc(0);
				system.led = 0;
				blink = (system.address + 3);
			}
			
			if (ui == (BUTTON_CFG + BUTTON_HOLD)) {
				AddressProc(EE_ADR_DEFAULT);
				system.address = AddressProc(0);
				system.led = 0;
				blink = (system.address + 3);
			}
							
			if (system.led == 0) {
				blink++;
				if (blink <= system.address) {
					UiLed(1);
				}				
				if (blink > (system.address + 5)) {
					blink = 0;
				}
			}
			
			if (system.led == MAIN_LED_CFG_BLINK) UiLed(0);
			system.led++;
			if (system.led >= MAIN_LED_CFG_PERIOD) system.led = 0;						
		}

		//---------------------------------------------------------
		ui = 0;
		_delay_ms(MAIN_DELAY);		
		WdtReset();
    }
}

//----------------------------------------------------
void HardInit(void) {
	WdtSet(7);
	ACSR = (1<<ACD);
	PRR = (1<<PRTIM1 | 1<<PRUSI | 1<<PRADC);
}

//----------------------------------------------------
uint8_t AddressProc(uint8_t new) {
	uint8_t adr;
	if (new > 0) {
		if ((new > EE_ADR_MAXVAL) || (new == 0)){
			new = EE_ADR_DEFAULT;
		}
		EEwrite(EE_ADR_LOCATION, new);
	}
	
	adr = EEread(EE_ADR_LOCATION);
	
	if ((adr > EE_ADR_MAXVAL) || (adr == 0)){
		adr = EE_ADR_DEFAULT;
	}

	return adr;
}
