/*
 * ui.c
 *
 * Created: 03.03.2017 14:23:24
 *  Author: dsosnowski
 */ 

//----------------------------------------------------
#define F_CPU 12000000
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "ui.h"
#include "defs.h"


#define LED_PORT			PORTB
#define LED_DDR				DDRB
#define LED_PIN				1
#define LED_SET				(LED_PORT |= (1<<LED_PIN))
#define LED_OFF				(LED_PORT &= ~(1<<LED_PIN))

#define SW1_GET				0		//always on

#define SW2_PORT			PORTB
#define SW2_IN				PINB
#define SW2_PIN				0
#define SW2_GET				(SW2_IN & (1<<SW2_PIN))

#define BUTTONS_CLICK_THR	3
#define BUTTONS_HOLD_THR	200



//----------------------------------------------------
struct {
	char states[NUM_OF_INPUTS];
	char actions;
} ui;

//----------------------------------------------------
void UiInit(void){
	LED_PORT |= (1<<LED_PIN | 1<<SW2_PIN);
	LED_DDR |= (1<<LED_PIN);	
}

//----------------------------------------------------
void UiLed(uint8_t state){
	if (state == 0) 
		LED_OFF;
	else
		LED_SET;
}

//----------------------------------------------------
uint8_t UiButtonProc(void){
	uint8_t state;
	uint8_t result = 0;
	uint8_t channel = 0;

	for(channel=0; channel<NUM_OF_INPUTS; channel++) {
		state = 1;
		
		if (channel == 0) {
			if (SW2_GET == 0) {
				state = 1;
			} else {
				state = SW1_GET;
			}
		}
		
		if (channel == 1) state = SW2_GET;

		if (state == 0){
			if (ui.states[channel] < 0xFF) {
				ui.states[channel]++;
				if (ui.states[channel] == BUTTONS_CLICK_THR) result = (channel + 1);
				if (ui.states[channel] == BUTTONS_HOLD_THR) result = (channel + 1 + BUTTON_HOLD);
			}
		} else {
			ui.states[channel] = 0;
		}
	}
	ui.actions = result;	
	
	return result;	
}
